Python API
==========


.. automodule:: fast_pauli


Pauli
-----

.. autoclass:: fast_pauli.Pauli
   :members:
   :special-members:


PauliString
-----------

.. autoclass:: fast_pauli.PauliString
   :members:
   :special-members:


PauliOp
-------

.. autoclass:: fast_pauli.PauliOp
   :members:
   :special-members:

SummedPauliOp
-------------

.. autoclass:: fast_pauli.SummedPauliOp
   :members:
   :special-members: